# vapor

![build](https://github.com/xiaket/vapor/workflows/build/badge.svg)
![PyPI version](https://badge.fury.io/py/vapor.svg)
![Coverage](https://coveralls.io/repos/github/xiaket/vapor/badge.svg)
![license](https://img.shields.io/pypi/l/vapor)

Vapor is an alternative way to write and manage your cloudformation stacks. Think of CDK, but with a promise to generate a template that is easy to understand and easy to manage. Also, if you are familiar with Django ORM, the way we define resources is really similar to how we define models in Django.
